@@ -4,9 +4,9 @@
 # license information.
 # -----------------------------------------------------------------------------
 
-"""Azure OSDU command line environment"""
+""" OSDU command line environment"""
 
 # from pkgutil import extend_path
 # __path__ = extend_path(__path__, __name__)
 
-__VERSION__ = '0.0.3'
+__VERSION__ = '0.0.7'
